Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
kwave/__init__.py | 4 | 0 | 0 | 100%
kwave/data.py | 45 | 13 | 0 | 71%
kwave/enums.py | 11 | 0 | 0 | 100%
kwave/executor.py | 37 | 25 | 0 | 32%
kwave/kWaveSimulation.py | 578 | 486 | 2 | 16%
kwave/kWaveSimulation_helper/__init__.py | 9 | 0 | 0 | 100%
kwave/kWaveSimulation_helper/create_absorption_variables.py | 57 | 45 | 0 | 21%
kwave/kWaveSimulation_helper/create_storage_variables.py | 206 | 191 | 0 | 7%
kwave/kWaveSimulation_helper/data_cast.py | 94 | 90 | 10 | 4%
kwave/kWaveSimulation_helper/display_simulation_params.py | 46 | 39 | 4 | 15%
kwave/kWaveSimulation_helper/expand_grid_matrices.py | 121 | 104 | 0 | 14%
kwave/kWaveSimulation_helper/retract_transducer_grid_size.py | 11 | 8 | 0 | 27%
kwave/kWaveSimulation_helper/save_to_disk_func.py | 204 | 180 | 50 | 12%
kwave/kWaveSimulation_helper/scale_source_terms_func.py | 130 | 107 | 0 | 18%
kwave/kWaveSimulation_helper/set_sound_speed_ref.py | 18 | 13 | 16 | 28%
kwave/kgrid.py | 275 | 148 | 0 | 46%
kwave/kmedium.py | 67 | 33 | 18 | 51%
kwave/ksensor.py | 39 | 15 | 0 | 62%
kwave/ksource.py | 140 | 102 | 0 | 27%
kwave/kspaceFirstOrder.py | 135 | 112 | 0 | 17%
kwave/kspaceFirstOrder2D.py | 74 | 62 | 0 | 16%
kwave/kspaceFirstOrder3D.py | 88 | 77 | 0 | 12%
kwave/kspaceFirstOrderAS.py | 87 | 77 | 0 | 11%
kwave/ktransducer.py | 268 | 212 | 0 | 21%
kwave/options.py | 183 | 153 | 0 | 16%
kwave/reconstruction/__init__.py | 0 | 0 | 0 | 100%
kwave/reconstruction/beamform.py | 57 | 57 | 0 | 0%
kwave/reconstruction/converter.py | 53 | 53 | 0 | 0%
kwave/reconstruction/shifted_transform.py | 7 | 7 | 0 | 0%
kwave/reconstruction/tools.py | 36 | 29 | 0 | 19%
kwave/recorder.py | 65 | 53 | 2 | 18%
kwave/utils/__init__.py | 16 | 0 | 0 | 100%
kwave/utils/abcdata.py | 8 | 8 | 0 | 0%
kwave/utils/checkutils.py | 32 | 22 | 0 | 31%
kwave/utils/colormap.py | 22 | 17 | 0 | 23%
kwave/utils/conversionutils.py | 128 | 110 | 0 | 14%
kwave/utils/datautils.py | 11 | 8 | 0 | 27%
kwave/utils/dotdictionary.py | 20 | 11 | 0 | 45%
kwave/utils/filterutils.py | 276 | 250 | 5 | 9%
kwave/utils/interputils.py | 177 | 142 | 0 | 20%
kwave/utils/ioutils.py | 173 | 60 | 0 | 65%
kwave/utils/kutils.py | 421 | 389 | 0 | 8%
kwave/utils/maputils.py | 1021 | 937 | 0 | 8%
kwave/utils/mathutils.py | 45 | 37 | 0 | 18%
kwave/utils/matrixutils.py | 116 | 93 | 0 | 20%
kwave/utils/misc.py | 47 | 34 | 0 | 28%
kwave/utils/osutils.py | 3 | 1 | 0 | 67%
kwave/utils/pmlutils.py | 52 | 49 | 0 | 6%
kwave/utils/tictoc.py | 12 | 0 | 0 | 100%
Total | 5725 | 4659 | 107 | 19%

No items found using the specified filter.